Francois Gouget : testbot/build: Move the build VM's scripts to the bin/ build directory.

Alexandre Julliard julliard at winehq.org
Thu Oct 11 15:32:48 CDT 2012


Module: tools
Branch: master
Commit: 1e48d99a79ccad889e917ef7a4a63509a749f330
URL:    http://source.winehq.org/git/tools.git/?a=commit;h=1e48d99a79ccad889e917ef7a4a63509a749f330

Author: Francois Gouget <fgouget at codeweavers.com>
Date:   Thu Oct 11 17:11:11 2012 +0200

testbot/build: Move the build VM's scripts to the bin/build directory.

---

 testbot/bin/WineRunBuild.pl                |    4 ++--
 testbot/bin/WineRunReconfig.pl             |   10 +++++-----
 testbot/bin/{ => build}/BuildSingleTest.pl |    4 ++--
 testbot/bin/{ => build}/Reconfig.pl        |    2 +-
 4 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/testbot/bin/WineRunBuild.pl b/testbot/bin/WineRunBuild.pl
index 2699351..56161da 100755
--- a/testbot/bin/WineRunBuild.pl
+++ b/testbot/bin/WineRunBuild.pl
@@ -1,7 +1,7 @@
 #!/usr/bin/perl -Tw
 #
 # Communicates with the build machine to have it perform the 'build' task.
-# See the bin/BuildSingleTest.pl script.
+# See the bin/build/Build.pl script.
 #
 # Copyright 2009 Ge van Geldorp
 #
@@ -241,7 +241,7 @@ if (defined($ErrMessage))
              $FullErrFileName, $Job, $Step, $Task;
 }
 my $Script = "#!/bin/sh\n";
-$Script .= "$BinDir/BuildSingleTest.pl $FileName " . $Step->FileType .
+$Script .= "$BinDir/build/BuildSingleTest.pl $FileName " . $Step->FileType .
            " $BaseName 32";
 if ($Run64)
 {
diff --git a/testbot/bin/BuildSingleTest.pl b/testbot/bin/build/BuildSingleTest.pl
similarity index 99%
rename from testbot/bin/BuildSingleTest.pl
rename to testbot/bin/build/BuildSingleTest.pl
index 07787d4..8d06614 100755
--- a/testbot/bin/BuildSingleTest.pl
+++ b/testbot/bin/build/BuildSingleTest.pl
@@ -29,7 +29,7 @@ sub BEGIN
   $0 =~ m=^(.*)/[^/]*$=;
   $Dir = $1;
 }
-use lib "$Dir/../lib";
+use lib "$Dir/../../lib";
 
 use WineTestBot::Config;
 
@@ -258,7 +258,7 @@ sub BuildTestExecutable
   }
   $TestExecutable .= "_test.exe";
   unlink("$DataDir/build-mingw${Bits}/$TestExecutable");
- 
+
   InfoMsg "Making test executable\n";
   system("( cd $DataDir/build-mingw$Bits && set -x && " .
          "  make -j$ncpus -C $TestsDir " .
diff --git a/testbot/bin/Reconfig.pl b/testbot/bin/build/Reconfig.pl
similarity index 99%
rename from testbot/bin/Reconfig.pl
rename to testbot/bin/build/Reconfig.pl
index f049e8a..c3f8eb4 100755
--- a/testbot/bin/Reconfig.pl
+++ b/testbot/bin/build/Reconfig.pl
@@ -29,7 +29,7 @@ sub BEGIN
   $0 =~ m=^(.*)/[^/]*$=;
   $Dir = $1;
 }
-use lib "$Dir/../lib";
+use lib "$Dir/../../lib";
 
 use WineTestBot::Config;
 




More information about the wine-cvs mailing list
diff --git a/testbot/bin/WineRunReconfig.pl b/testbot/bin/WineRunReconfig.pl
index 4aacd81..ae102e9 100755
--- a/testbot/bin/WineRunReconfig.pl
+++ b/testbot/bin/WineRunReconfig.pl
@@ -1,7 +1,7 @@
 #!/usr/bin/perl -Tw
 #
 # Communicates with the build machine to have it perform the 'reconfig' task.
 # See the bin/Reconfig.pl script.
 #
 # Copyright 2009 Ge van Geldorp
 #
@@ -194,7 +194,7 @@ if (defined($ErrMessage))
   FatalError "Can't set VM status to running: $ErrMessage\n",
              $FullErrFileName, $Job, $Step, $Task;
 }
-my $Script = "#!/bin/sh\n$BinDir/Reconfig.pl\n";
+my $Script = "#!/bin/sh\n$BinDir/build/Reconfig.pl\n";
 $ErrMessage = $VM->RunScriptInGuestTimeout("", $Script, $Task->Timeout);
 if (defined($ErrMessage))
 {
@@ -212,10 +212,10 @@ if (defined($ErrMessage))
   FatalError "Can't copy log from VM: $ErrMessage\n", $FullErrFileName,
              $Job, $Step, $Task;
 }
-my $ReconfigSucceeded = ProcessRawlog($FullRawlogFileName, $FullLogFileName,
-                                      $FullErrFileName);
+my $Success = ProcessRawlog($FullRawlogFileName, $FullLogFileName,
+                              $FullErrFileName);
 
-if ($ReconfigSucceeded)
+if ($Success)
 {
   $ErrMessage = $VM->RemoveSnapshot($VM->IdleSnapshot);
   if (defined($ErrMessage))
@@ -1,7 +1,7 @@
 #
 # Communicates with the build machine to have it perform the 'reconfig' task.
-# See the bin/Reconfig.pl script.
+# See the bin/build/Reconfig.pl script.
 #
 # Copyright 2009 Ge van Geldorp